@@ -8,10 +8,8 @@ package Strict::Perl;
 # Copyright (c) 2014, 2015, 2017 INABA Hitoshi <ina@cpan.org> in a CPAN
 ######################################################################
 
-$VERSION =
-$VERSION = '2017.01';
+$Strict::Perl::VERSION = 2017.02;
 
-BEGIN { pop @INC if $INC[-1] eq '.' } # CVE-2016-1238: Important unsafe module load path flaw
 use 5.00503;
 use strict;
 local $^W = 1;
@@ -277,7 +275,7 @@ sub import {
         die "Incorrect use of module '${\__PACKAGE__}' at $filename line $line.\n";
     }
 
-    # must VARSION require
+    # must VERSION require
     unless ($VERSION_called) {
         my($package,$filename,$line) = caller;
         die "$self $Strict::Perl::VERSION version required like 'use $self $Strict::Perl::VERSION;', stopped at $filename line $line.\n";
@@ -387,7 +385,7 @@ Strict::Perl - Perl module to restrict old/unsafe constructs
 
 =head1 SYNOPSIS
 
-  use Strict::Perl 2017.01; # must version, must match
+  use Strict::Perl 2017.02; # must version, must match
 
 =head1 DESCRIPTION
 
@@ -399,7 +397,7 @@ in your script.
 
 Version specify is required when use Strict::Perl, like;
 
-  use Strict::Perl 2017.01;
+  use Strict::Perl 2017.02;
 
 It's die if specified version doesn't match Strict::Perl's version.
 
